@@ -7,8 +7,9 @@ from .gsheets import get_sheet_rows
 ITEM_ROWS = 9
 
 
-def get_rows(spreadsheet_name='RDR2 Collecting Needs', sheet_name="Tom"):
-    return get_sheet_rows(spreadsheet_name, sheet_name)
+def get_rows(spreadsheet_name='RDR2 Collecting Needs', sheet_name="T"):
+    rows = get_sheet_rows(spreadsheet_name, sheet_name)
+    return [list(map(str.strip, row)) for row in rows]
 
 
 def get_col_item_needs(rows):
